Here is a patch that checks for the revision numbers instead of simply the
inquiry string (and adds my buggy revision):

--- wfd.c.orig  Thu Feb 18 17:06:08 1999
+++ wfd.c       Mon Jun  7 12:02:25 1999
@@ -243,17 +243,21 @@
                return -1;

        /*
         * The IOMEGA ZIP 100, at firmware 21.* and 23.* at least
         * is known to lock up if transfers > 64 blocks are
         * requested.
         */
-       if (!strcmp(ap->model, "IOMEGA  ZIP 100       ATAPI")) {
-               printf("wfd%d: buggy Zip drive, 64-block transfer limit
set\n",
-                      t->lun);
-               t->maxblks = 64;
-       } else {
-               t->maxblks = 0; /* no limit */
-       }
+
+       if (!strncmp(ap->model, "IOMEGA  ZIP 100       ATAPI", 27))
+               if ((!strncmp(ap->revision, "12", 2)) ||
+                   (!strncmp(ap->revision, "21", 2)) ||
+                   (!strncmp(ap->revision, "23", 2))) {
+                       printf("wfd%d: buggy Zip drive, 64-block transfer 
limit set\n",
+                       t->lun);
+                       t->maxblks = 64;
+               } else {
+                       t->maxblks = 0; /* no limit */
+               }


-----
@@ -243,17 +243,21 @@

        /*
-        * The IOMEGA ZIP 100, at firmware 21.* and 23.* at least
+        * The IOMEGA ZIP 100, at firmware 12.A, 21.* and 23.* at least
         * is known to lock up if transfers > 64 blocks are
         * requested.
Chris D. Faulhaber <jed...@fxp.org>  |  All the true gurus I've met never
System/Network Administrator,        |  claimed they were one, and always
Reality Check Information, Inc.      |  pointed to someone better.




To Unsubscribe: send mail to majord...@freebsd.org
with "unsubscribe freebsd-hackers" in the body of the message

Reply via email to